Crate auxtools_impl
auxtools_
impl
0.1.0
All Items
Crate Items
Macros
Attribute Macros
Crate
auxtools_
impl
Macros

convert_
signature
Attribute Macros

hook
The
hook
attribute is used to define functions that may be used as proc hooks, and to optionally hook those procs upon library initialization.
init
runtime_
handler
shutdown